Welcome to the Tidewave documentation.

Tidewave is the complete AI dev toolkit for full-stack Phoenix and Rails. It is a collection of tools that you use on your day to day to become more productive while using coding agents to build web applications. It includes:

  • Tidewave IDE: an agentic dev environment for Phoenix and Rails. Design, develop, test, and review alongside your web app in the browser. Your agent sees what you see.

  • Tidewave Toolbar: nspect, debug, and improve your UI with framework-aware context for your coding agent.

  • Tidewave MCP: connect your coding agent to your web framework, allowing it to run code, query your database, read the docs for your exact dependencies and more.

How to read these docs

Each page in this documentation covers a different feature or topic. Therefore you can read them in any order.

Additionally, the sidebar is organized as follows:

  • Tidewave: baseline features which are provided by the Tidewave Toolbar and Tidewave IDE

  • Tidewave IDE: features exclusive to our agentic dev environment

  • Tidewave MCP: instructions on how to configure your favorite coding agent to use Tidewave MCP

  • References: a general collection of articles on assorted topics