A GitHub Copilot subscription will give you access to models from Anthropic, OpenAI, xAI, and other providers. Simply choose GitHub Copilot as your provider in Settings and follow the authentication steps.

You can control which Copilot models are available to Tidewave in your GitHub Copilot settings.

Copilot through OpenCode

You can also use GitHub Copilot with OpenCode. First connect Tidewave to OpenCode. Once connceted, select "Add models", and then pick GitHub as one of the providers. This method also supports GitHub Enterprise. See our OpenCode documentation to learn more.