Tidewave IDE is an agentic dev environment for Phoenix and Rails. It is an IDE that runs in the browser, allowing your coding agent to seamlessly interact with your web application. See our Tidewave IDE page for more information.
Tidewave IDE is an additional product which requires installing a desktop app (or additional CLI tools).
Tidewave vs Tidewave IDE
This page is about installing the Tidewave IDE, which is an agentic IDE that runs in your browser. If you are looking for the Tidewave Toolbar and Tidewave Connect, follow the steps to install the Tidewave package instead.
Installing the app
To get started with Tidewave IDE, download our desktop app:
- For macOS: Apple Silicon, Intel
- For Linux: AppImage (x86_64), AppImage (ARM64)
- For Windows: Windows (the desktop app is also recommended when using WSL)
After installation, an icon should appear in your menu bar (top-right on macOS and Linux, bottom-right on Windows).
We also offer a CLI if you are running your application remotely, inside containers, or other cases where the desktop application is not an option. If you are using Docker, read our containers guide.
Running Tidewave IDE
After installation, you can run the Tidewave IDE application. By default, it will run a service on http://localhost:9832, which you can access from your favorite browser. Once you do, you will be greeted with this screen:

Then you can put the address of your web application and Tidewave IDE will connect to it. If your web application was not yet configured with Tidewave IDE, you will be prompted to do so, using the links below:
- Tidewave IDE for Phoenix
- Tidewave IDE for Ruby on Rails
- Tidewave IDE for TanStack Start
- Tidewave IDE for Vite
The Tidewave IDE app will remain running on your menu bar (top right on macOS/Linux, bottom right on Windows), you can click it to open up, configure, and update Tidewave IDE.
Remember Tidewave IDE must always run on the same machine as your web server is running. If your web server is running on a separate machine, you will want to use our CLI.
CLI
For running Tidewave IDE inside containers and other advanced uses, a CLI is also available:
- For macOS: Apple Silicon, Intel
- For Windows: Windows
- For Linux: aarch64-gnu, aarch64-musl, x86_64-gnu, x86_64-musl
Once the CLI is installed, run it with ./tidewave. Run ./tidewave --help for a list of all options.
For security reasons, the CLI only allows access from the same machine it is running on by default. Furthermore, it enforces that the CLI is being accessed from localhost or 127.0.0.1. If you want to run the CLI on a custom server, you must pass --allow-remote-access and --allowed-origins=https://HOSTNAME:PORT respectively to change our defaults. You can also enable HTTPS certificates both for the App and the CLI.