You can use your microphone to control the agent. Simply click the microphone icon, close to the send button, and start dictating.

Browser considerations

Note the voice input is fully controlled by your browser, which implies:

  • The browser uses your default microphone. You can change which microphone to use either in your browser settings or in your Operating System.

  • The browser uses your default language. You can configure your default language in your browser settings.

  • The browser may use remote services for speech recognition. Some browsers (typically Chromium based browsers like Chrome, Edge, etc.) offer the ability to perform on-device recognition for certain languages. You can choose this option in Tidewave settings.

  • Not all browsers have speech recognition available (neither remotely or on-device).

Tips

Here are some useful tips for making the best of voice input:

  • While using the voice input, you can still use the Inspector or click on lines during Code Review, and Tidewave should correctly inject them as part of your speech. However, some browsers require you to briefly pause before clicking.

  • Use Ctrl+Shift+M (or Cmd+Shift+M on macOS) to quickly toggle voice input.